@@ -12,7 +12,7 @@ use strict;
 use warnings;
 
 package App::RouterColorizer;
-$App::RouterColorizer::VERSION = '1.212301';
+$App::RouterColorizer::VERSION = '1.212302';
 use Moose;
 
 use feature 'signatures';
@@ -225,6 +225,9 @@ s/^ ( $INTERFACE \Q is \E \N+ \Q, line protocol is \E \N+          ) $/$self->_c
     $line =~ s/^ ( \Q  Up \E   \N+ ) $/$self->_colorize($1, $GREEN)/exx;
     $line =~ s/^ ( \Q  Down \E \N+ ) $/$self->_colorize($1, $RED)/exx;
 
+    # "show int" description lines
+    $line =~ s/^ ( \Q \E? \Q Description: \E \N+ ) $/$self->_colorize($1, $INFO)/exx;
+
     # "show int" rates
     $line =~
 s/^ ( \Q  \E $NUM \s \w+ \s (?: input | output) \s rate \s $NUM \s \N+ ) $/$self->_colorize($1, $INFO)/exx;
@@ -420,7 +423,7 @@ App::RouterColorizer - Colorize router CLI output
 
 =head1 VERSION
 
-version 1.212301
+version 1.212302
 
 =head1 DESCRIPTION
 
